% File src/library/stats/man/Binomial.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{Binomial}
\alias{Binomial}
\alias{dbinom}
\alias{pbinom}
\alias{qbinom}
\alias{rbinom}
\title{The Binomial Distribution}
\description{
  パラメータ \code{size} と \code{prob} の二項分布の
  密度，分布関数，クォンタイル関数そして乱数生成．

  これは慣習的に
  \code{size} 回の試行中の \sQuote{成功} の回数と解釈される．
}
\usage{
dbinom(x, size, prob, log = FALSE)
pbinom(q, size, prob, lower.tail = TRUE, log.p = FALSE)
qbinom(p, size, prob, lower.tail = TRUE, log.p = FALSE)
rbinom(n, size, prob)
}
\arguments{
  \item{x, q}{クォンタイルのベクトル．}
  \item{p}{確率のベクトル．}
  \item{n}{観測値．もし \code{length(n) > 1} なら長さが
    必要な個数とされる．}
  \item{size}{試行数(ゼロかそれ以上)．}
  \item{prob}{各試行の成功確率．}
  \item{log, log.p}{論理値；もし TRUE なら確率 p は log(p) とされる．}
  \item{lower.tail}{論理値；もし TRUE (既定値)なら
    確率は \eqn{P[X \le x]} で，さもなければ \eqn{P[X > x]}．}
}
\value{
  \code{dbinom} は密度，\code{pbinom} は分布関数，
  \code{qbinom} はクォンタイル関数，そして
  \code{rbinom} は乱数を生成する．

  もし \code{size} が整数でなければ \code{NaN} が返される．
  
  結果の長さは
  他の関数に対しては数値引数の長さの最大値である．
  
  \code{n} 以外の数値引数は結果の長さまでリサイクルされる．
  論理値引数の最初の値だけが使われる．
}
\details{
  \code{size} \eqn{= n} で \code{prob} \eqn{= p} の二項分布は密度
  \deqn{p(x) = {n \choose x} {p}^{x} {(1-p)}^{n-x}}{
    p(x) = choose(n, x) p^x (1-p)^(n-x)}
  を \eqn{x = 0, \ldots, n} に対して持つ．
  \emph{二項係数}は \R では
  \code{\link{choose}} で計算できることを注意する．

  もし \code{x} の要素が整数でなければ \code{dbinom}
  の結果はゼロとなり警告が出る．

  \eqn{p(x)} は Loader のアルゴリズムを用いて起算される，下の参考文献を
  見よ．

  クォンタイルは
  \eqn{F(x) \ge p} となる最少の \eqn{x} として計算される，
  ここで \eqn{F} は分布関数である．
}
\seealso{
  負の二項分布 \code{\link{dnbinom}} や
  ポアッソン分布 \code{\link{dpois}} を含む
  他の標準分布に対しては \link{Distributions}．
}
\source{
  \code{dbinom} に対してはサドルポイント展開が使われる：
  次を見よ

  Catherine Loader (2000). \emph{Fast and Accurate Computation of
    Binomial Probabilities}; 
  \url{http://www.herine.net/stat/software/dbinom.html} から
  入手可能．

  \code{pbinom} は \code{\link{pbeta}} を使う．

  \code{qbinom} は正規近似の歪度補正を含む Cornish--Fisher 展開を
  使う．
  %Expansion to include a skewness
  %correction to a normal approximation, followed by a search.

  \code{rbinom} (\code{size < .Machine$integer.max} に対して)は
  次に基づく

  Kachitvichyanukul, V. and Schmeiser, B. W. (1988)
  Binomial random variate generation.
  \emph{Communications of the ACM}, \bold{31}, 216--222.

  より大きな値に対しては逆関数を使う．
}
\examples{
require(graphics)
# X Binomial(100,0.5) に対して P(45 < X < 55) を計算
sum(dbinom(46:54, 100, 0.5))

## 拡大範囲に対して "log = TRUE" を使う：
n <- 2000
k <- seq(0, n, by = 20)
plot (k, dbinom(k, n, pi/10, log = TRUE), type = "l", ylab = "log density",
      main = "dbinom(*, log=TRUE) is better than  log(dbinom(*))")
lines(k, log(dbinom(k, n, pi/10)), col = "red", lwd = 2)
## extreme points are omitted since dbinom gives 0.
mtext("dbinom(k, log=TRUE)", adj = 0)
mtext("extended range", adj = 0, line = -1, font = 4)
mtext("log(dbinom(k))", col = "red", adj = 1)
}
\keyword{distribution}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/Binomial.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{Binomial}
%\alias{Binomial}
%\alias{dbinom}
%\alias{pbinom}
%\alias{qbinom}
%\alias{rbinom}
%\title{The Binomial Distribution}
%\description{
%  Density, distribution function, quantile function and random
%  generation for the binomial distribution with parameters \code{size}
%  and \code{prob}.
%
%  This is conventionally interpreted as the number of \sQuote{successes}
%  in \code{size} trials.
%}
%\usage{
%dbinom(x, size, prob, log = FALSE)
%pbinom(q, size, prob, lower.tail = TRUE, log.p = FALSE)
%qbinom(p, size, prob, lower.tail = TRUE, log.p = FALSE)
%rbinom(n, size, prob)
%}
%\arguments{
%  \item{x, q}{vector of quantiles.}
%  \item{p}{vector of probabilities.}
%  \item{n}{number of observations. If \code{length(n) > 1}, the length
%    is taken to be the number required.}
%  \item{size}{number of trials (zero or more).}
%  \item{prob}{probability of success on each trial.}
%  \item{log, log.p}{logical; if TRUE, probabilities p are given as log(p).}
%  \item{lower.tail}{logical; if TRUE (default), probabilities are
%    \eqn{P[X \le x]}, otherwise, \eqn{P[X > x]}.}
%}
%\value{
%  \code{dbinom} gives the density, \code{pbinom} gives the distribution
%  function, \code{qbinom} gives the quantile function and \code{rbinom}
%  generates random deviates.
%
%  If \code{size} is not an integer, \code{NaN} is returned.
%  
%  The length of the result is determined by \code{n} for
%  \code{rbinom}, and is the maximum of the lengths of the
%  numerical arguments for the other functions.  
%  
%  The numerical arguments other than \code{n} are recycled to the
%  length of the result.  Only the first elements of the logical
%  arguments are used.
%}
%\details{
%  The binomial distribution with \code{size} \eqn{= n} and
%  \code{prob} \eqn{= p} has density
%  \deqn{p(x) = {n \choose x} {p}^{x} {(1-p)}^{n-x}}{
%    p(x) = choose(n, x) p^x (1-p)^(n-x)}
%  for \eqn{x = 0, \ldots, n}.
%  Note that binomial \emph{coefficients} can be computed by
%  \code{\link{choose}} in \R.
%
%  If an element of \code{x} is not integer, the result of \code{dbinom}
%  is zero, with a warning.
%
%  \eqn{p(x)} is computed using Loader's algorithm, see the reference below.
%
%  The quantile is defined as the smallest value \eqn{x} such that
%  \eqn{F(x) \ge p}, where \eqn{F} is the distribution function.
%}
%\seealso{
%  \link{Distributions} for other standard distributions, including
%  \code{\link{dnbinom}} for the negative binomial, and
%  \code{\link{dpois}} for the Poisson distribution.
%}
%\source{
%  For \code{dbinom} a saddle-point expansion is used: see
%
%  Catherine Loader (2000). \emph{Fast and Accurate Computation of
%    Binomial Probabilities}; available from
%  \url{http://www.herine.net/stat/software/dbinom.html}.
%
%  \code{pbinom} uses \code{\link{pbeta}}.
%
%  \code{qbinom} uses the Cornish--Fisher Expansion to include a skewness
%  correction to a normal approximation, followed by a search.
%
%  \code{rbinom} (for \code{size < .Machine$integer.max}) is based on
%
%  Kachitvichyanukul, V. and Schmeiser, B. W. (1988)
%  Binomial random variate generation.
%  \emph{Communications of the ACM}, \bold{31}, 216--222.
%
%  For larger values it uses inversion.
%}
%\examples{
%require(graphics)
%# Compute P(45 < X < 55) for X Binomial(100,0.5)
%sum(dbinom(46:54, 100, 0.5))
%
%## Using "log = TRUE" for an extended range :
%n <- 2000
%k <- seq(0, n, by = 20)
%plot (k, dbinom(k, n, pi/10, log = TRUE), type = "l", ylab = "log density",
%      main = "dbinom(*, log=TRUE) is better than  log(dbinom(*))")
%lines(k, log(dbinom(k, n, pi/10)), col = "red", lwd = 2)
%## extreme points are omitted since dbinom gives 0.
%mtext("dbinom(k, log=TRUE)", adj = 0)
%mtext("extended range", adj = 0, line = -1, font = 4)
%mtext("log(dbinom(k))", col = "red", adj = 1)
%}
%\keyword{distribution}
%
%\encoding{UTF-8}
%