% File src/library/stats/man/constrOptim.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2010 R Core Team
% Distributed under GPL 2 or later

\name{constrOptim}
\alias{constrOptim}
%%\title{Linearly Constrained Optimization}
\title{線形不等式制約最小化}
\description{
線形不等式制約の下で関数を適応的バリヤアルゴリズムで最小化する．
}
\usage{
constrOptim(theta, f, grad, ui, ci, mu = 1e-04, control = list(),
            method = if(is.null(grad)) "Nelder-Mead" else "BFGS",
            outer.iterations = 100, outer.eps = 1e-05, \dots,
            hessian = FALSE)
}
\arguments{
  \item{theta}{数値(ベクトル)初期値(長さ \eqn{p})：
    ありそうな領域中にある必要．}
  \item{f}{最小化される関数(下を見よ)．}
  \item{grad}{
    \code{f} のグラディエント(同様に関数)，
    又は \code{NULL} (下を見よ)．}
  \item{ui}{制約行列(\eqn{k \times p}{k x p})，下を見よ．}
  \item{ci}{長さ \eqn{k} の制約ベクトル(下を見よ)．}
  \item{mu}{(小さな)調整用パラメータ．}
  \item{control, method, hessian}{\code{\link{optim}} に渡される．}
  \item{outer.iterations}{バリヤアルゴリズムの繰り返し回数．}
  \item{outer.eps}{非負数；バリヤアルゴリズムの相対的収束
    判定の許容度．}
  \item{\dots}{
    \code{f} と \code{grad} に渡される他の名前付き引数：
    \code{\link{optim}} を通じて渡される必要があるので
    その名前付き引数とマッチしてはならない．}
}
\details{
  ありそうな領域は
  \code{ui \%*\% theta - ci >= 0} で定義される．
  初期値はこの領域の内部になければならないが，
  最小値は境界にあるかもしれない．

  制約を強化するために対数バリヤが加えられ，
  それから \code{\link{optim}} が呼び出される．バリヤ関数は
  目的関数が各外部繰り返しで減少するように選ばれる．
  ありそうな領域の内部の最小値は典型的に極めて速やかに
  見つかるが，境界上の最小値に対しては相当な回数の
  外部繰り返しが必要かもしれない．

  調整パラメータ \code{mu} はバリヤ項に掛けられる．
  その正確な値はしばしば相対的に重要ではない．
  \code{mu} が増加するにつれて増補された目的関数は
  元の関数に近づいていくが，同時に
  ありそうな領域の境界近くではより滑らかでなくなる．

  目的関数の無現値を許す任意の \code{optim} メソッドが
  使える(現在は "L-BFGS-B" のみ)．

  目的関数 \code{f} は最初の引数として
  最小化がそれについて行われるパラメータのベクトルを持つ．
  それはスカラー値を返さなければならない．
  オプションの引数 \code{\dots} は
  \code{optim} に渡され，そしてそれから(もし \code{optim} によって
  使われなければ) \code{f} に渡される．
  \code{optim} と同様に既定では最小化であるが，
  \code{control$fnscale} を負の値にすれば最大化が実行される．

  グラディエント関数 \code{grad} は
  \code{method = "Nelder-Mead"} を除いては与える必要がある．
  これは \code{f} のそれらにマッチする引数を取り，
  そしてグラディエントを含むベクトルを返すべきである．

}
\value{
  \code{\link{optim}} に対するようなものであるが，
  二つの余分の成分を持つ：
  \code{barrier.value} は最適値でのバリヤ関数の値を与え，
  \code{outer.iterations} は外部繰り返し(\code{optim} への呼び出し)
  の回数を与える．
  
  \code{counts} 成分は
  全ての \code{\link{optim}()$counts} の\emph{和}である．
}

\references{
  K. Lange \emph{Numerical Analysis for Statisticians.} Springer
  2001, p185ff
}

\seealso{
  \code{\link{optim}}，特に矩形制約最適化を行う \code{method = "L-BFGS-B"}．
}

\examples{\donttest{
## optim から
fr <- function(x) {   ## Rosenbrock のバナナ関数
    x1 <- x[1]
    x2 <- x[2]
    100 * (x2 - x1 * x1)^2 + (1 - x1)^2
}
grr <- function(x) { ## 'fr' のグラディエント
    x1 <- x[1]
    x2 <- x[2]
    c(-400 * x1 * (x2 - x1 * x1) - 2 * (1 - x1),
       200 *      (x2 - x1 * x1))
}

optim(c(-1.2,1), fr, grr)
# 矩形制約，最適値は境界上
constrOptim(c(-1.2,0.9), fr, grr, ui = rbind(c(-1,0), c(0,-1)), ci = c(-1,-1))
#  x <= 0.9,  y - x > 0.1
constrOptim(c(.5,0), fr, grr, ui = rbind(c(-1,0), c(1,-1)), ci = c(-0.9,0.1))


## 線形と二次プログラミング問題を解く
## 但し良い初期値が必要
#
# from example(solve.QP) in 'quadprog'
# no derivative
fQP <- function(b) {-sum(c(0,5,0)*b)+0.5*sum(b*b)}
Amat       <- matrix(c(-4,-3,0,2,1,0,0,-2,1), 3, 3)
bvec       <- c(-8, 2, 0)
constrOptim(c(2,-1,-1), fQP, NULL, ui = t(Amat), ci = bvec)
# 微分
gQP <- function(b) {-c(0, 5, 0) + b}
constrOptim(c(2,-1,-1), fQP, gQP, ui = t(Amat), ci = bvec)

## 最小化ではなく最大化
hQP <- function(b) {sum(c(0,5,0)*b)-0.5*sum(b*b)}
constrOptim(c(2,-1,-1), hQP, NULL, ui = t(Amat), ci = bvec,
            control = list(fnscale = -1))
}}
\keyword{optimize}


\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/constrOptim.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2010 R Core Team
%% Distributed under GPL 2 or later
%
%\name{constrOptim}
%\alias{constrOptim}
%\title{Linearly Constrained Optimization}
%\description{
%Minimise a function subject to linear inequality constraints using an
%adaptive barrier algorithm.
%}
%\usage{
%constrOptim(theta, f, grad, ui, ci, mu = 1e-04, control = list(),
%            method = if(is.null(grad)) "Nelder-Mead" else "BFGS",
%            outer.iterations = 100, outer.eps = 1e-05, \dots,
%            hessian = FALSE)
%}
%\arguments{
%  \item{theta}{numeric (vector) starting value (of length \eqn{p}): must
%    be in the feasible region.}
%  \item{f}{function to minimise (see below).}
%  \item{grad}{gradient of \code{f} (a \code{\link{function}} as well),
%    or \code{NULL} (see below).}
%  \item{ui}{constraint matrix (\eqn{k \times p}{k x p}), see below.}
%  \item{ci}{constraint vector of length \eqn{k} (see below).}
%  \item{mu}{(Small) tuning parameter.}
%  \item{control, method, hessian}{passed to \code{\link{optim}}.}
%  \item{outer.iterations}{iterations of the barrier algorithm.}
%  \item{outer.eps}{non-negative number; the relative convergence
%    tolerance of the barrier algorithm.}
%  \item{\dots}{Other named arguments to be passed to \code{f} and \code{grad}:
%    needs to be passed through \code{\link{optim}} so should not match its
%    argument names.}
%}
%\details{
%  The feasible region is defined by \code{ui \%*\% theta - ci >= 0}. The
%  starting value must be in the interior of the feasible region, but the
%  minimum may be on the boundary.
%
%  A logarithmic barrier is added to enforce the constraints and then
%  \code{\link{optim}} is called. The barrier function is chosen so that
%  the objective function should decrease at each outer iteration. Minima
%  in the interior of the feasible region are typically found quite
%  quickly, but a substantial number of outer iterations may be needed
%  for a minimum on the boundary.
%
%  The tuning parameter \code{mu} multiplies the barrier term. Its precise
%  value is often relatively unimportant. As \code{mu} increases the
%  augmented objective function becomes closer to the original objective
%  function but also less smooth near the boundary of the feasible
%  region.
%
%  Any \code{optim} method that permits infinite values for the
%  objective function may be used (currently all but "L-BFGS-B").
%
%  The objective function \code{f} takes as first argument the vector
%  of parameters over which minimisation is to take place.  It should
%  return a scalar result. Optional arguments \code{\dots} will be
%  passed to \code{optim} and then (if not used by \code{optim}) to
%  \code{f}. As with \code{optim}, the default is to minimise, but
%  maximisation can be performed by setting \code{control$fnscale} to a
%  negative value.
%
%  The gradient function \code{grad} must be supplied except with
%  \code{method = "Nelder-Mead"}.  It should take arguments matching
%  those of \code{f} and return a vector containing the gradient.
%
%}
%\value{
%  As for \code{\link{optim}}, but with two extra components:
%  \code{barrier.value} giving the value of the barrier function at the
%  optimum and \code{outer.iterations} gives the
%  number of outer iterations (calls to \code{optim}).
%  The \code{counts} component contains the \emph{sum} of all
%  \code{\link{optim}()$counts}.
%}
%
%\references{
%  K. Lange \emph{Numerical Analysis for Statisticians.} Springer
%  2001, p185ff
%}
%
%\seealso{
%  \code{\link{optim}}, especially \code{method = "L-BFGS-B"} which
%  does box-constrained optimisation.
%}
%
%\examples{\donttest{
%## from optim
%fr <- function(x) {   ## Rosenbrock Banana function
%    x1 <- x[1]
%    x2 <- x[2]
%    100 * (x2 - x1 * x1)^2 + (1 - x1)^2
%}
%grr <- function(x) { ## Gradient of 'fr'
%    x1 <- x[1]
%    x2 <- x[2]
%    c(-400 * x1 * (x2 - x1 * x1) - 2 * (1 - x1),
%       200 *      (x2 - x1 * x1))
%}
%
%optim(c(-1.2,1), fr, grr)
%#Box-constraint, optimum on the boundary
%constrOptim(c(-1.2,0.9), fr, grr, ui = rbind(c(-1,0), c(0,-1)), ci = c(-1,-1))
%#  x <= 0.9,  y - x > 0.1
%constrOptim(c(.5,0), fr, grr, ui = rbind(c(-1,0), c(1,-1)), ci = c(-0.9,0.1))
%
%
%## Solves linear and quadratic programming problems
%## but needs a feasible starting value
%#
%# from example(solve.QP) in 'quadprog'
%# no derivative
%fQP <- function(b) {-sum(c(0,5,0)*b)+0.5*sum(b*b)}
%Amat       <- matrix(c(-4,-3,0,2,1,0,0,-2,1), 3, 3)
%bvec       <- c(-8, 2, 0)
%constrOptim(c(2,-1,-1), fQP, NULL, ui = t(Amat), ci = bvec)
%# derivative
%gQP <- function(b) {-c(0, 5, 0) + b}
%constrOptim(c(2,-1,-1), fQP, gQP, ui = t(Amat), ci = bvec)
%
%## Now with maximisation instead of minimisation
%hQP <- function(b) {sum(c(0,5,0)*b)-0.5*sum(b*b)}
%constrOptim(c(2,-1,-1), hQP, NULL, ui = t(Amat), ci = bvec,
%            control = list(fnscale = -1))
%}}
%\keyword{optimize}
%
%
%\encoding{UTF-8}
%
